/*
Scribble - gui.js
Copyright (C) 2012 Greg Sydney-Smith

This file is part of Scribble.

Scribble is free software: you can redistribute it and/or modify it under the
terms of the GNU Lesser General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scribble is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along
with Scribble.  If not, see <http://www.gnu.org/licenses/>.

Revision History:
2012-12-31 Added onClick func as param to GuiBtn/2
2012-12-30 From CPC project.
2012-06-17 Created.
*/

function GuiText(page,x,y,w,h,id,text,args) {
    // constructor
    this.page = page;
    this.id   = id;
    this.x    = x;
    this.y    = y;
    this.w    = w;
    this.h    = h;
    this.text = text;
    this.args = args;
    
    this.create = function() {
        var o1 = document.createTextNode(this.text)
        var o2 = document.createElement('p');
        o2.setAttribute('id',this.page+this.id+'_p');
        o2.appendChild(o1);
        var o3 = document.createElement('div');
        o3.setAttribute('id'   ,this.page+this.id);
        o3.setAttribute('class','tlabel');
        o3.appendChild(o2);
        document.getElementById(this.page).appendChild(o3);
    }
    this.create();
    
    this.resize = function (aw,ah) {
        var x = this.x*aw;
        var y = this.y*ah;
        var w = this.w*aw-4;
        var h = this.h*ah-4;
        resizer.resizeIdStyle0(this.page+this.id,x,y,w,h);
        resizer.resizeIdFont(this.page+this.id,0.5*h);
    }
}

function GuiTextbox(page,x,y,w,h,id,args) {
    // constructor
    this.page = page;
    this.id   = id;
    this.x    = x;
    this.y    = y;
    this.w    = w;
    this.h    = h;
    this.args = args;
    
    this.create = function() {
        var o = document.createElement('input');
        o.setAttribute('id'   ,this.page+this.id);
        o.setAttribute('class','abs');
        o.setAttribute('type', 'text');
        o.setAttribute('name',this.page+this.id);
        o.setAttribute('size', '50');
        document.getElementById(this.page).appendChild(o); 
    }
    this.create();
    
    this.resize = function (aw,ah) {
        var x = this.x*aw;
        var y = this.y*ah;
        var w = this.w*aw-0;
        var h = this.h*ah-0;
        resizer.resizeIdStyle0(this.page+this.id,x,y,w,h);
        resizer.resizeIdFont(this.page+this.id,0.5*h);
    }
}

function GuiBtn(page,x,y,w,h,id,text,args) {
    // constructor
    this.page = page;
    this.id   = id;
    this.x    = x;
    this.y    = y;
    this.w    = w;
    this.h    = h;
    this.text = text;
    this.args = args;
    
    this.create = function() {
        var action = (args[0]=="") ? "On"+this.page+this.id+"()" : args[0];
        var o1 = document.createTextNode(this.text)
        var o2 = document.createElement('p');
        o2.setAttribute('class','label');
        o2.appendChild(o1);
        var o3 = document.createElement('div');
        o3.setAttribute('id'   ,this.page+this.id);
        o3.setAttribute('class','btn');
        o3.appendChild(o2);
        var o4 = document.createElement('a');
        o4.setAttribute('href' ,'#');
        o4.setAttribute('onClick' ,action);
        o4.appendChild(o3);
        document.getElementById(page).appendChild(o4);
    }
    this.create();
    
    this.resize = function (aw,ah) {
        var x = this.x*aw;
        var y = this.y*ah;
        var w = this.w*aw-4;
        var h = this.h*ah-4;
        // qtr=parseInt(0.25*h,10); top=2+qtr; bot=parseInt(2+h-3*qtr,10)
        resizer.resizeIdStyle0(this.page+this.id,x,y,w,h);
        resizer.resizeIdFont(this.page+this.id,0.5*h);
    }
}

function GuiBtn2(page,x,y,w,h,id,text,args) {
    // constructor
    this.page = page;
    this.id   = id;
    this.x    = x;
    this.y    = y;
    this.w    = w;
    this.h    = h;
    this.text = text;
    this.args = args;
    this.el   = null;
    
    this.create = function() {
        var action = (args[0]=="") ? "On"+this.page+this.id+"()" : args[0];
        var o1 = document.createTextNode(this.text)
        var o3 = document.createElement('div');
        o3.setAttribute('id'   ,this.page+this.id);
        o3.setAttribute('class','btn');
        o3.appendChild(o1);
        var o4 = document.createElement('a');
        o4.setAttribute('href' ,'#');
        o4.setAttribute('onClick' ,action);
        o4.appendChild(o3);
        document.getElementById(page).appendChild(o4);
        this.el = o4;
    }
    this.create();
    
    this.resize = function (aw,ah) {
        var x = this.x*aw;
        var y = this.y*ah;
        var w = this.w*aw-4;
        var h = this.h*ah-4;
        resizer.resizeIdStyle0(this.page+this.id,x,y,w,h);
        resizer.resizeIdFont(this.page+this.id,0.5*h);
    }
}

function GuiList(page,x,y,w,h,id,lines,args) {
    // constructor
    this.page = page;
    this.id   = id;
    this.x    = x;
    this.y    = y;
    this.w    = w;
    this.h    = h;
    this.lines= lines;
    this.args = args;
    
    this.create = function() {
        var o = document.createElement('select');
        o.setAttribute('id'   ,this.page+this.id);
        o.setAttribute('class','gsslist');
        o.setAttribute('name' ,this.page+this.id);
        o.setAttribute('size' ,'10');
        // if (eval(page+id+'Change')) onChange
        o.setAttribute('onChange',this.page+this.id+'Change()');
        document.getElementById(this.page).appendChild(o); 
    }
    this.create();
    
    this.resize = function (aw,ah) {
        var x = this.x*aw;
        var y = this.y*ah;
        var w = this.w*aw-4;
        var h = this.h*ah-4;
        resizer.resizeIdStyle0(this.page+this.id,x,y,w,h);
        resizer.resizeIdFont(this.page+this.id,h/this.lines);
    }
}

function GuiDrop(page,x,y,w,h,id,args) {
    // constructor
    this.page = page;
    this.id   = id;
    this.x    = x;
    this.y    = y;
    this.w    = w;
    this.h    = h;
    this.args = args;
    
    this.create = function() {
        var o = document.createElement('select');
        o.setAttribute('id'   ,this.page+this.id);
        o.setAttribute('class','abs');
        o.setAttribute('name' ,this.page+this.id);
        // if (typeof page+id+'Change' === 'function')
        o.setAttribute('onChange',this.page+this.id+'Change()');
        document.getElementById(this.page).appendChild(o); 
    }
    this.create();
    
    this.resize = function (aw,ah) {
        var x = this.x*aw;
        var y = this.y*ah;
        var w = this.w*aw-4;
        var h = this.h*ah-4;
        resizer.resizeIdStyle0(this.page+this.id,x,y,w,h);
        resizer.resizeIdFont(this.page+this.id,h/2);
    }
}

function GuiRadioBtn(page,x,y,w,h,group,n,val) {
    // constructor
    this.page = page;
    this.group= group;
    this.n    = n;
    this.x    = x;
    this.y    = y;
    this.w    = w;
    this.h    = h;
    this.val  = val;
    
//    <input type="radio" name="printer" value="1"> Printer 1<br>

    this.create = function() {
        var o   = document.createElement("input");
        o.type  = "radio";
        o.id    = this.page+this.group+this.n;
        o.name  = this.page+this.group;
        o.value = this.val;
        o.setAttribute('class','abs');
        document.getElementById(this.page).appendChild(o); 
    }
    this.create();
    
    this.resize = function (aw,ah) {
        var x = this.x*aw;
        var y = this.y*ah;
        var w = this.w*aw-4;
        var h = this.h*ah-4;
        resizer.resizeIdStyle0(this.page+this.group+this.n,x,y,w,h);
        resizer.resizeIdFont(this.page+this.group+this.n,h/2);
    }
}

/*
<html>
<head>
<script>
 
function clearRadioGroup(grp) {
  for (var i=0; i<20; i++) {
    var o2 = document.getElementById(grp+'_'+i+'_img');
    if (o2)
      o2.setAttribute('src','radio-off.png');
  }
}
 
function setRadio(o) {
  // alert(o.tagName);
  // alert(o.id);
  var a = o.id.split('_');
  clearRadioGroup(a[0]);
  var o2 = document.getElementById(o.id+'_img');
  // alert(o.id+' src='+o2.getAttribute('src'));
  o2.setAttribute('src','radio-on.png');
}
 
function toggleCheck(o) {
  // alert(o.tagName);
  // alert(o.id);
  var o2 = document.getElementById(o.id+'_img');
  alert(o.id+' src='+o2.getAttribute('src'));
  var x= (o2.getAttribute('src').slice(-12) == 'check-on.png');
  o2.setAttribute('src','check-'+(x? 'off' : 'on')+'.png');
}
 
</script>
</head>
<body>
<a id="abc_1" href="#" onClick="setRadio(this)"><img src="radio-off.png" id="abc_1_img" /></a><br />
<a id="abc_2" href="#" onClick="setRadio(this)"><img src="radio-off.png" id="abc_2_img" /></a><br />
<a id="abc_3" href="#" onClick="setRadio(this)"><img src="radio-off.png" id="abc_3_img" /></a>
</body>
</html>

*/
