/*
Scribble - resize.js
Copyright (C) 2012 Greg Sydney-Smith

This file is part of Scribble.

Scribble is free software: you can redistribute it and/or modify it under the
terms of the GNU Lesser General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scribble is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along
with Scribble.  If not, see <http://www.gnu.org/licenses/>.

Revision History:
2012-12-?? Improved font sizing.
2012-12-30 From HP67 project.
*/

function Resizer() {
    this.dw= document.documentElement.clientWidth -4;
    this.dh= document.documentElement.clientHeight-4;
    var aspect = false;
    var aspect_width = this.dw;
    var aspect_height= this.dh;
    this.aw= this.dw;
    this.ah= this.dh;
    
    this.setAspectRatio = function (w,h) {
        aspect = true;
        aspect_width = w;  // units are independent of device pixels
        aspect_height= h;  // could be 10000 or 0.794
    }

    this.resize = function () {
        this.dw= document.documentElement.clientWidth -4; // allow 2px app border
        this.dh= document.documentElement.clientHeight-4;
        this.aw= this.dw;
        this.ah= this.dh;

        if (aspect) {
            var scaleX= this.dw/aspect_width;
            var scaleY= this.dh/aspect_height;
            var scale= Math.min(scaleX,scaleY);
            this.aw = parseInt(scale*aspect_width ,10);
            this.ah = parseInt(scale*aspect_height,10);
        }
    }

    this.size  = function (x) { return parseInt(x*this.ah+0.5,10); }
    this.sizew = function (x) { return parseInt(x*this.aw+0.5,10); }

    this.resizeAppDiv = function (Id) {
        var o= document.getElementById(Id);
        o.style.marginLeft  = parseInt((this.dw-this.aw)/2,10)+"px";
        o.style.marginTop   = parseInt((this.dh-this.ah)/2,10)+"px";
        o.style.width = this.aw+"px"; // assumes 0 margin, border, padding for app
        o.style.height= this.ah+"px";
    }

    this.resizeId = function (Id,dx,dy) {
        var o= document.getElementById(Id);
        o.width =dx;
        o.height=dy;
    }

    // raw, no adjustment for extant padding etc
    this.resizeIdStyle0 = function (Id,x,y,dx,dy) {
        var o= document.getElementById(Id);
        o.style.left  = parseInt(x +0.5,10)+"px";
        o.style.top   = parseInt(y +0.5,10)+"px";
        o.style.width = parseInt(dx+0.5,10)+"px";
        o.style.height= parseInt(dy+0.5,10)+"px";
    }

    // bType= eg "solid black"
    // lines=1,2,3...;
    // fh= fontHeight in pixels (includes descenders)
    // lh= lineHeight in multiples of fontHeight, typically (lines==1)? 1 : 1.2;
    this.createStyle = function (w,h,m,b,p,bType,lines,lh,fh,align) {
        var o = new Object;
        o.width     = parseInt(w,10);
        o.height    = parseInt(h,10);
        o.margin    = parseInt(m,10);
        o.border    = parseInt(b,10);
        o.padding   = parseInt(p,10);
        o.borderType= bType;
        o.lines     = parseInt(lines,10);
        o.fontHeight= parseInt(fh,10);
        o.lineHeight= parseFloat(lh);
        o.vAlign    = align;
        return o;
    }
    
    // raw, no adjustment for extant padding etc
    // absolute positioning locates the top left of the outside
    // only w and h need to be reduced by m,b,p
    // extra padding will be added to top/bottom to valign
    // use other means to align left/right/center within the box
    this.useStyle = function (id,x,y,style) {
        x= parseInt(x,10);
        y= parseInt(y,10);
        var w = style.width;
        var h = style.height;
        var m = style.margin;
        var b = style.border;
        var p = style.padding;
        var ih= style.lineHeight*style.fontHeight*style.lines;  // inner height
        
        var o= document.getElementById(id);
        o.style.left  = x+"px";
        o.style.top   = y+"px";
        o.style.width = (w-2*m-2*b-2*p)+"px";
        o.style.height= ih+"px";
        o.style.margin= m+"px";
        o.style.border= b+"px "+style.borderType;

        o.style.paddingLeft=   p+"px";
        o.style.paddingRight=  p+"px";

        var padding= h-2*m-2*b-ih;
        switch (style.vAlign) {
        case "t": o.style.paddingTop=    p+"px";
                  o.style.paddingBottom= (padding-p)+"px";
        case "b": o.style.paddingTop=    (padding-p)+"px";
                  o.style.paddingBottom= p+"px";
        default : var half= parseInt(padding/2,10);
                  o.style.paddingTop=    half+"px";
                  o.style.paddingBottom= (padding-half)+"px";
        }
        
        o.style.fontSize= style.fontHeight+"px";
        o.style.lineHeight= style.lineHeight;
    }


    this.resizeIdStyle = function (Id,x,y,dx,dy) {
        var o= document.getElementById(Id);
        o.style.left  = parseInt(x+0.5,10)+"px";
        o.style.top   = parseInt(y+0.5,10)+"px";
        o.style.width = contentWidth( o,dx)+"px";
        o.style.height= contentHeight(o,dy)+"px";
    }

    this.resizeDivImg = function (div,img,x,y,dx,dy) {
        this.resizeIdStyle(div,x,y,dx,dy);
        this.resizeId(img,dx,dy);
    }

    this.resizeIdFont = function (Id,dy) {
        document.getElementById(Id).style.fontSize=parseInt(dy+0.5,10)+"px";
    }

    this.resizeButton = function (id,x,y,w,h,frac) {
        var o = document.getElementById(id);
        var h0= h-2; // 1px border. cant use contentHeight() because we change padding
        var h1= parseInt(frac*h0+0.5,10);
        var h2= parseInt((h0-h1)/2,10);
        o.style.left  = parseInt(x+0.5,10)+"px";
        o.style.top   = parseInt(y+0.5,10)+"px";
        o.style.width = contentWidth( o,w)+"px";
        o.style.height= h1+"px";
        o.style.fontSize=h1+"px";
        o.style.paddingTop=    h2+"px";
        o.style.paddingBottom= h2+"px";
    }

    // labels are without a border or margin and have zero padding on the left
    // you can left align or center the text by other means
    // you should set h to 1 or more times the lineHeight in pixels.
    // w and h are inner dimensions, allow extra space for mbp when positioning.
    this.resizeLbl = function (id,x,y,w,lines,lh) {
        var o= document.getElementById(id);
        o.style.top=  parseInt(y,10)+"px";
        o.style.left= parseInt(x,10)+"px";
        o.style.width = parseInt(w,10)+"px";
        o.style.height= parseInt(lines*lh,10)+"px";
        o.style.margin=  "0px";
        o.style.border=  "0px solid black";
        o.style.paddingLeft= "0px";
        o.style.paddingRight= "0px";
        o.style.paddingTop= "2px";
        o.style.paddingBottom= "2px";
        o.style.fontSize= parseInt(lh/1.2,10)+"px"; // assumes linespacing = 1.2 x font size (the default)
    }

    // buttons have a 1px black border, m=0
    // w and h are inside values. h>=lines*lh
    // text will be centered vertically (use other things to center horiz)
    this.resizeBtn = function (id,x,y,w,h,lines,lh) {
        var o= document.getElementById(id);
        var half = parseInt((h-lines*lh)/2,10);
        o.style.top=  parseInt(y,10)+"px";
        o.style.left= parseInt(x,10)+"px";
        o.style.width = parseInt(w,10)+"px";
        o.style.height= parseInt(lines*lh,10)+"px";
        o.style.margin=  "0px";
        o.style.border=  "1px solid black";
        o.style.paddingLeft= "2px";
        o.style.paddingRight= "2px";
        o.style.paddingTop= half+"px";
        o.style.paddingBottom= parseInt(h-half-lines*lh,10)+"px"; // this should be an int but isn't always due to floats being used
        o.style.fontSize= parseInt(lh/1.2,10)+"px"; // assumes linespacing = 1.2 x font size (the default)
    }


    function contentWidth(o,dx) {
        var w= parseInt(dx+0.5,10);
        var deducts = [ o.style.marginLeft, o.style.borderLeft, o.style.paddingLeft,
               o.style.marginRight, o.style.borderRight, o.style.paddingRight];
        for (var i=0; i<deducts.length; i++) {
            var x = parseInt(deducts[i],10); if (isNaN(x)) x=0;
            w -= x;
        }
        return w;
    }
    function contentHeight(o,dy) {
        var h= parseInt(dy+0.5,10);
        var deducts = [ o.style.marginTop, o.style.borderTop, o.style.paddingTop,
               o.style.marginBottom, o.style.borderBottom, o.style.paddingBottom];
        for (var i=0; i<deducts.length; i++) {
            var x = parseInt(deducts[i],10); if (isNaN(x)) x=0;
            h -= x;
        }
        return h;
    }
}
